Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type SMS ¶
func (*SMS) GetURLQuery ¶
GetURLQuery generates the body that the http request needs
type SMSConfig ¶
type SMSConfig struct {
APPKey string
APPSecret string
// The sms signature. The value must be as same
// as the accessible signature in alidayu management
// center. The sample: 阿里大于. Required field
FreeSignName string
// The sms template parameters. key-value format.
// The key must be as same as ones in the template.
// The sample: {"code":"1234","product":"alidayu"}
// Optional field.
Param map[string]string
// Phone number. The samle: 13000000000.
// Required field.
PhoneNumber string
// Sms template ID. The value must be as same as
// the accessible signature in alidayu management
// center. The sample: SMS_585014
TemplateCode string
}
type SMSParam ¶
type SMSParam struct {
Extend string `json:"extend"`
Type string `json:"sms_type"`
FreeSignName string `json:"sms_free_sign_name"`
Param map[string]string `json:"sms_param"`
ReceiverNumber string `json:"rec_num"`
TemplateCode string `json:"sms_template_code"`
Method string `json:"method"`
APPKey string `json:"app_key"`
TargetAPPKey string `json:"target_app_key"`
SignMethod string `json:"sign_method"`
Sign string `json:"sign"`
Session string `json:"session"`
TimeStamp string `json:"timestamp"`
Format string `json:"format"`
V string `json:"v"`
PartnerID string `json:"partner_id"`
Simplify bool `json:"simplify"`
}
Click to show internal directories.
Click to hide internal directories.